# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/changes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=systemathics/apis/services/corporate_actions/v1/changes.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\x99\x01\n\x0e\x43hangesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x45\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateInterval\"X\n\x0f\x43hangesResponse\x12\x45\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x37.systemathics.apis.services.corporate_actions.v1.Change\"`\n\x06\x43hange\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\x12\n\nnew_symbol\x18\x02 \x01(\t\x12\x12\n\nold_symbol\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x01\x32\x9f\x01\n\x0e\x43hangesService\x12\x8c\x01\n\x07\x43hanges\x12?.systemathics.apis.services.corporate_actions.v1.ChangesRequest\x1a@.systemathics.apis.services.corporate_actions.v1.ChangesResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.corporate_actions.v1.changes_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHANGESREQUEST._serialized_start=244
  _CHANGESREQUEST._serialized_end=397
  _CHANGESRESPONSE._serialized_start=399
  _CHANGESRESPONSE._serialized_end=487
  _CHANGE._serialized_start=489
  _CHANGE._serialized_end=585
  _CHANGESSERVICE._serialized_start=588
  _CHANGESSERVICE._serialized_end=747
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/static_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;systemathics/apis/services/static_data/v1/static_data.proto\x12)systemathics.apis.services.static_data.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xb4\x05\n\x11StaticDataRequest\x12H\n\nasset_type\x18\x01 \x01(\x0e\x32\x34.systemathics.apis.services.static_data.v1.AssetType\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x65xchange\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06ticker\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0f\x66uture_contract\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0f\x66uture_category\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14\x63rypto_base_currency\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15\x63rypto_quote_currency\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\requity_sector\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05index\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04\x63ode\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x05start\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12*\n\x05\x63ount\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\xc1\x03\n\x12StaticDataResponse\x12G\n\x07\x66utures\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.FutureEntry\x12H\n\x08\x65quities\x18\x02 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.EquityEntry\x12\x41\n\x04\x65tfs\x18\x03 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.EtfEntry\x12\x46\n\x07indices\x18\x04 \x03(\x0b\x32\x35.systemathics.apis.services.static_data.v1.IndexEntry\x12G\n\x07\x63ryptos\x18\x05 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.CryptoEntry\x12\x44\n\x05\x66orex\x18\x06 \x03(\x0b\x32\x35.systemathics.apis.services.static_data.v1.ForexEntry\"\xc9\x08\n\x0b\x45quityEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07primary\x18\x03 \x01(\t\x12\x11\n\toperating\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08\x63urrency\x18\x06 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x07 \x01(\t\x12K\n\x0etick_size_rule\x18\x08 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSize\x12\r\n\x05index\x18\t \x03(\t\x12\'\n\x04open\x18\n \x01(\x0b\x32\x19.google.protobuf.Duration\x12(\n\x05\x63lose\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12+\n\x05price\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x06volume\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1f\n\x04time\x18\x11 \x01(\x0b\x32\x11.google.type.Date\x12\x0f\n\x07sources\x18\x12 \x01(\x05\x12T\n\x07mapping\x18\x13 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.MappingEntry\x12\x11\n\tbloomberg\x18\x14 \x01(\t\x12\x0f\n\x07reuters\x18\x15 \x01(\t\x12\x13\n\x0bmorningstar\x18\x16 \x01(\t\x12\x0c\n\x04\x66igi\x18\x17 \x01(\t\x12\r\n\x05\x66igic\x18\x18 \x01(\t\x12\x0c\n\x04isin\x18\x19 \x01(\t\x12\r\n\x05\x63usip\x18\x1a \x01(\t\x12\r\n\x05sedol\x18\x1b \x01(\t\x12\x0b\n\x03\x63ik\x18\x1c \x01(\t\x12T\n\x07sectors\x18\x1d \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntry\x12\x34\n\x0e\x63\x61pitalization\x18\x1e \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x13\n\x0b\x64\x65scription\x18\x1f \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18  \x01(\t\x12\r\n\x05phone\x18! \x01(\t\x12\r\n\x05\x65mail\x18\" \x01(\t\x12\x0b\n\x03url\x18# \x01(\t\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cSectorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc0\x08\n\x08\x45tfEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07primary\x18\x03 \x01(\t\x12\x11\n\toperating\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08\x63urrency\x18\x06 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x07 \x01(\t\x12K\n\x0etick_size_rule\x18\x08 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSize\x12\r\n\x05index\x18\t \x03(\t\x12\'\n\x04open\x18\n \x01(\x0b\x32\x19.google.protobuf.Duration\x12(\n\x05\x63lose\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12+\n\x05price\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x06volume\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1f\n\x04time\x18\x11 \x01(\x0b\x32\x11.google.type.Date\x12\x0f\n\x07sources\x18\x12 \x01(\x05\x12Q\n\x07mapping\x18\x13 \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.EtfEntry.MappingEntry\x12\x11\n\tbloomberg\x18\x14 \x01(\t\x12\x0f\n\x07reuters\x18\x15 \x01(\t\x12\x13\n\x0bmorningstar\x18\x16 \x01(\t\x12\x0c\n\x04\x66igi\x18\x17 \x01(\t\x12\r\n\x05\x66igic\x18\x18 \x01(\t\x12\x0c\n\x04isin\x18\x19 \x01(\t\x12\r\n\x05\x63usip\x18\x1a \x01(\t\x12\r\n\x05sedol\x18\x1b \x01(\t\x12\x0b\n\x03\x63ik\x18\x1c \x01(\t\x12Q\n\x07sectors\x18\x1d \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntry\x12\x34\n\x0e\x63\x61pitalization\x18\x1e \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x13\n\x0b\x64\x65scription\x18\x1f \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18  \x01(\t\x12\r\n\x05phone\x18! \x01(\t\x12\r\n\x05\x65mail\x18\" \x01(\t\x12\x0b\n\x03url\x18# \x01(\t\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cSectorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x08\n\x0b\x46utureEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07primary\x18\x03 \x01(\t\x12\x11\n\toperating\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08\x63urrency\x18\x06 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x07 \x01(\t\x12K\n\x0etick_size_rule\x18\x08 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSize\x12\r\n\x05index\x18\t \x03(\t\x12\'\n\x04open\x18\n \x01(\x0b\x32\x19.google.protobuf.Duration\x12(\n\x05\x63lose\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12+\n\x05price\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x06volume\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1f\n\x04time\x18\x11 \x01(\x0b\x32\x11.google.type.Date\x12\x0f\n\x07sources\x18\x12 \x01(\x05\x12T\n\x07mapping\x18\x13 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.FutureEntry.MappingEntry\x12\x11\n\tbloomberg\x18\x14 \x01(\t\x12\x0f\n\x07reuters\x18\x15 \x01(\t\x12\x13\n\x0bmorningstar\x18\x16 \x01(\t\x12\x0c\n\x04\x66igi\x18\x17 \x01(\t\x12\r\n\x05\x66igic\x18\x18 \x01(\t\x12\x12\n\nunderlying\x18\x19 \x01(\t\x12\x10\n\x08\x63ontract\x18\x1a \x01(\t\x12V\n\x08\x63\x61tegory\x18\x1b \x03(\x0b\x32\x44.systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntry\x12\r\n\x05\x63hain\x18\x1c \x01(\t\x12#\n\x08maturity\x18\x1d \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05month\x18\x1e \x01(\t\x12\x0c\n\x04year\x18\x1f \x01(\x05\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rCategoryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x96\x06\n\nIndexEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07primary\x18\x03 \x01(\t\x12\x11\n\toperating\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08\x63urrency\x18\x06 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x07 \x01(\t\x12K\n\x0etick_size_rule\x18\x08 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSize\x12\r\n\x05index\x18\t \x03(\t\x12\'\n\x04open\x18\n \x01(\x0b\x32\x19.google.protobuf.Duration\x12(\n\x05\x63lose\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12+\n\x05price\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x06volume\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1f\n\x04time\x18\x11 \x01(\x0b\x32\x11.google.type.Date\x12\x0f\n\x07sources\x18\x12 \x01(\x05\x12S\n\x07mapping\x18\x13 \x03(\x0b\x32\x42.systemathics.apis.services.static_data.v1.IndexEntry.MappingEntry\x12\x11\n\tbloomberg\x18\x14 \x01(\t\x12\x0f\n\x07reuters\x18\x15 \x01(\t\x12\x13\n\x0bmorningstar\x18\x16 \x01(\t\x12\x0c\n\x04\x66igi\x18\x17 \x01(\t\x12\r\n\x05\x66igic\x18\x18 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x19 \x01(\t\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x07\n\x0b\x43ryptoEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07primary\x18\x03 \x01(\t\x12\x11\n\toperating\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x15\n\rbase_currency\x18\x06 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x07 \x01(\t\x12K\n\x0etick_size_rule\x18\x08 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSize\x12\r\n\x05index\x18\t \x03(\t\x12\'\n\x04open\x18\n \x01(\x0b\x32\x19.google.protobuf.Duration\x12(\n\x05\x63lose\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12+\n\x05price\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x06volume\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1f\n\x04time\x18\x11 \x01(\x0b\x32\x11.google.type.Date\x12\x0f\n\x07sources\x18\x12 \x01(\x05\x12T\n\x07mapping\x18\x13 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.CryptoEntry.MappingEntry\x12\x11\n\tbloomberg\x18\x14 \x01(\t\x12\x0f\n\x07reuters\x18\x15 \x01(\t\x12\x13\n\x0bmorningstar\x18\x16 \x01(\t\x12\x0c\n\x04\x66igi\x18\x17 \x01(\t\x12\r\n\x05\x66igic\x18\x18 \x01(\t\x12\x16\n\x0equote_currency\x18\x19 \x01(\t\x12\x11\n\tconsensus\x18\x1a \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x1b \x01(\t\x12%\n\nissue_date\x18\x1c \x01(\x0b\x32\x11.google.type.Date\x12\x34\n\x0e\x63\x61pitalization\x18\x1d \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x1a\n\x12\x63irculating_supply\x18\x1e \x01(\x05\x12\x12\n\nmax_supply\x18\x1f \x01(\x05\x12\x14\n\x0ctotal_supply\x18  \x01(\x05\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x06\n\nForexEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07primary\x18\x03 \x01(\t\x12\x11\n\toperating\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x15\n\rbase_currency\x18\x06 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x07 \x01(\t\x12K\n\x0etick_size_rule\x18\x08 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSize\x12\r\n\x05index\x18\t \x03(\t\x12\'\n\x04open\x18\n \x01(\x0b\x32\x19.google.protobuf.Duration\x12(\n\x05\x63lose\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12+\n\x05price\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x06volume\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1f\n\x04time\x18\x11 \x01(\x0b\x32\x11.google.type.Date\x12\x0f\n\x07sources\x18\x12 \x01(\x05\x12S\n\x07mapping\x18\x13 \x03(\x0b\x32\x42.systemathics.apis.services.static_data.v1.ForexEntry.MappingEntry\x12\x11\n\tbloomberg\x18\x14 \x01(\t\x12\x0f\n\x07reuters\x18\x15 \x01(\t\x12\x13\n\x0bmorningstar\x18\x16 \x01(\t\x12\x0c\n\x04\x66igi\x18\x17 \x01(\t\x12\r\n\x05\x66igic\x18\x18 \x01(\t\x12\x16\n\x0equote_currency\x18\x19 \x01(\t\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x08TickSize\x12\r\n\x05price\x18\x01 \x01(\x01\x12\x0c\n\x04tick\x18\x02 \x01(\x01*\xc0\x01\n\tAssetType\x12\x1a\n\x16\x41SSET_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41SSET_TYPE_ALL\x10\x01\x12\x15\n\x11\x41SSET_TYPE_EQUITY\x10\x02\x12\x15\n\x11\x41SSET_TYPE_FUTURE\x10\x03\x12\x12\n\x0e\x41SSET_TYPE_ETF\x10\x04\x12\x14\n\x10\x41SSET_TYPE_INDEX\x10\x05\x12\x15\n\x11\x41SSET_TYPE_CRYPTO\x10\x06\x12\x14\n\x10\x41SSET_TYPE_FOREX\x10\x07\x32\x9f\x01\n\x11StaticDataService\x12\x89\x01\n\nStaticData\x12<.systemathics.apis.services.static_data.v1.StaticDataRequest\x1a=.systemathics.apis.services.static_data.v1.StaticDataResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.static_data.v1.static_data_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EQUITYENTRY_MAPPINGENTRY._options = None
  _EQUITYENTRY_MAPPINGENTRY._serialized_options = b'8\001'
  _EQUITYENTRY_SECTORSENTRY._options = None
  _EQUITYENTRY_SECTORSENTRY._serialized_options = b'8\001'
  _ETFENTRY_MAPPINGENTRY._options = None
  _ETFENTRY_MAPPINGENTRY._serialized_options = b'8\001'
  _ETFENTRY_SECTORSENTRY._options = None
  _ETFENTRY_SECTORSENTRY._serialized_options = b'8\001'
  _FUTUREENTRY_MAPPINGENTRY._options = None
  _FUTUREENTRY_MAPPINGENTRY._serialized_options = b'8\001'
  _FUTUREENTRY_CATEGORYENTRY._options = None
  _FUTUREENTRY_CATEGORYENTRY._serialized_options = b'8\001'
  _INDEXENTRY_MAPPINGENTRY._options = None
  _INDEXENTRY_MAPPINGENTRY._serialized_options = b'8\001'
  _CRYPTOENTRY_MAPPINGENTRY._options = None
  _CRYPTOENTRY_MAPPINGENTRY._serialized_options = b'8\001'
  _FOREXENTRY_MAPPINGENTRY._options = None
  _FOREXENTRY_MAPPINGENTRY._serialized_options = b'8\001'
  _ASSETTYPE._serialized_start=7255
  _ASSETTYPE._serialized_end=7447
  _STATICDATAREQUEST._serialized_start=246
  _STATICDATAREQUEST._serialized_end=938
  _STATICDATARESPONSE._serialized_start=941
  _STATICDATARESPONSE._serialized_end=1390
  _EQUITYENTRY._serialized_start=1393
  _EQUITYENTRY._serialized_end=2490
  _EQUITYENTRY_MAPPINGENTRY._serialized_start=2396
  _EQUITYENTRY_MAPPINGENTRY._serialized_end=2442
  _EQUITYENTRY_SECTORSENTRY._serialized_start=2444
  _EQUITYENTRY_SECTORSENTRY._serialized_end=2490
  _ETFENTRY._serialized_start=2493
  _ETFENTRY._serialized_end=3581
  _ETFENTRY_MAPPINGENTRY._serialized_start=2396
  _ETFENTRY_MAPPINGENTRY._serialized_end=2442
  _ETFENTRY_SECTORSENTRY._serialized_start=2444
  _ETFENTRY_SECTORSENTRY._serialized_end=2490
  _FUTUREENTRY._serialized_start=3584
  _FUTUREENTRY._serialized_end=4611
  _FUTUREENTRY_MAPPINGENTRY._serialized_start=2396
  _FUTUREENTRY_MAPPINGENTRY._serialized_end=2442
  _FUTUREENTRY_CATEGORYENTRY._serialized_start=4564
  _FUTUREENTRY_CATEGORYENTRY._serialized_end=4611
  _INDEXENTRY._serialized_start=4614
  _INDEXENTRY._serialized_end=5404
  _INDEXENTRY_MAPPINGENTRY._serialized_start=2396
  _INDEXENTRY_MAPPINGENTRY._serialized_end=2442
  _CRYPTOENTRY._serialized_start=5407
  _CRYPTOENTRY._serialized_end=6410
  _CRYPTOENTRY_MAPPINGENTRY._serialized_start=2396
  _CRYPTOENTRY_MAPPINGENTRY._serialized_end=2442
  _FOREXENTRY._serialized_start=6413
  _FOREXENTRY._serialized_end=7211
  _FOREXENTRY_MAPPINGENTRY._serialized_start=2396
  _FOREXENTRY_MAPPINGENTRY._serialized_end=2442
  _TICKSIZE._serialized_start=7213
  _TICKSIZE._serialized_end=7252
  _STATICDATASERVICE._serialized_start=7450
  _STATICDATASERVICE._serialized_end=7609
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_bollinger.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/daily_analytics/v1/daily_bollinger.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x16google/type/date.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xd7\x01\n\x15\x44\x61ilyBollingerRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x45\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateInterval\x12\x0e\n\x06length\x18\x03 \x01(\x05\x12\x11\n\tdeviation\x18\x04 \x01(\x01\x12\x12\n\nadjustment\x18\x05 \x01(\x08\"i\n\x16\x44\x61ilyBollingerResponse\x12O\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.daily_analytics.v1.DailyBollingerData\"\xcc\x01\n\x12\x44\x61ilyBollingerData\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05value\x18\x02 \x01(\x01\x12+\n\x05lower\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x05upper\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x06middle\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue2\xb7\x01\n\x15\x44\x61ilyBollingerService\x12\x9d\x01\n\x0e\x44\x61ilyBollinger\x12\x44.systemathics.apis.services.daily_analytics.v1.DailyBollingerRequest\x1a\x45.systemathics.apis.services.daily_analytics.v1.DailyBollingerResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily_analytics.v1.daily_bollinger_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYBOLLINGERREQUEST._serialized_start=280
  _DAILYBOLLINGERREQUEST._serialized_end=495
  _DAILYBOLLINGERRESPONSE._serialized_start=497
  _DAILYBOLLINGERRESPONSE._serialized_end=602
  _DAILYBOLLINGERDATA._serialized_start=605
  _DAILYBOLLINGERDATA._serialized_end=809
  _DAILYBOLLINGERSERVICE._serialized_start=812
  _DAILYBOLLINGERSERVICE._serialized_end=995
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/dividends.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?systemathics/apis/services/corporate_actions/v1/dividends.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\x9b\x01\n\x10\x44ividendsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x45\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateInterval\"\\\n\x11\x44ividendsResponse\x12G\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x39.systemathics.apis.services.corporate_actions.v1.Dividend\"\x97\x01\n\x08\x44ividend\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12K\n\x04type\x18\x02 \x01(\x0e\x32=.systemathics.apis.services.corporate_actions.v1.DividendType\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x01\x12\r\n\x05score\x18\x04 \x01(\x01*^\n\x0c\x44ividendType\x12\x1d\n\x19\x44IVIDEND_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x44IVIDEND_TYPE_CASH\x10\x01\x12\x17\n\x13\x44IVIDEND_TYPE_STOCK\x10\x02\x32\xa7\x01\n\x10\x44ividendsService\x12\x92\x01\n\tDividends\x12\x41.systemathics.apis.services.corporate_actions.v1.DividendsRequest\x1a\x42.systemathics.apis.services.corporate_actions.v1.DividendsResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.corporate_actions.v1.dividends_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DIVIDENDTYPE._serialized_start=651
  _DIVIDENDTYPE._serialized_end=745
  _DIVIDENDSREQUEST._serialized_start=246
  _DIVIDENDSREQUEST._serialized_end=401
  _DIVIDENDSRESPONSE._serialized_start=403
  _DIVIDENDSRESPONSE._serialized_end=495
  _DIVIDEND._serialized_start=498
  _DIVIDEND._serialized_end=649
  _DIVIDENDSSERVICE._serialized_start=748
  _DIVIDENDSSERVICE._serialized_end=915
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/action.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-systemathics/apis/type/shared/v1/action.proto\x12 systemathics.apis.type.shared.v1*B\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x0e\n\nACTION_SET\x10\x01\x12\x10\n\x0c\x41\x43TION_CLEAR\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.action_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACTION._serialized_start=83
  _ACTION._serialized_end=149
# @@protoc_insertion_point(module_scope)
